
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.18.8',
    'branch_nick': 'patch-0-Rucio_1_18_8_preparation',
    'revision_id': '493566e11ffc6b3623aaa7479a6871c63d725067',
    'revno': 7384
}
